==> flamingock-core-api-0.0.19-beta-sources.jar: io/flamingock/core/api/annotations/ChangeUnit.java <==
/*
 * Copyright 2023 Flamingock (https://oss.flamingock.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.flamingock.core.api.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;


@Target(ElementType.TYPE)
@Retention(RetentionPolicy.RUNTIME)
public @interface ChangeUnit {

    /**
     * Change unit's id. It will be used to identify both change entries, the one linked to @Execution and @BeforeExecution(this one with the suffix `_before`)
     * Equivalent to field `id` in ChangeSet annotation
     *
     * @return Change unit's id
     */
    String id();

    /**
     * Equivalent to field `order` in ChangeSet annotation and ChangeLog,
     * as now there is only one "changeSet", annotated with @Execution
     *
     * @return ChangeSet's author
     */
    String order();

    /**
     * Equivalent to field `author` in ChangeSet annotation
     *
     * @return ChangeSet's author
     */
    String author() default "";

    /**
     * Equivalent to field `failFast` in ChangeSet annotation
     *
     * @return ChangeSet if the ChangeLog is fail fast
     */
    boolean failFast() default true;

    /**
     * Equivalent to field `runAlways` in ChangeSet annotation
     *
     * @return ChangeSet if the ChangeLog is runAlways
     */
    @Deprecated
    boolean runAlways() default false;

    /**
     * Equivalent to field `systemVersion` in ChangeSet annotation
     *
     * @return ChangeSet if the ChangeLog is runAlways
     */
    String systemVersion() default "0";

    /**
     * If true, Mongock will try to run the changeUnit in a native transaction, if possible.
     *
     * @return If he changeUnit should be run in a native transaction.
     */
    boolean transactional() default true;

}

==> flamingock-core-api-0.0.22-beta-sources.jar: io/flamingock/core/api/annotations/ChangeUnit.java <==
/*
 * Copyright 2023 Flamingock (https://oss.flamingock.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.flamingock.core.api.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;


@Target(ElementType.TYPE)
@Retention(RetentionPolicy.RUNTIME)
public @interface ChangeUnit {

    /**
     * Change unit's id. It will be used to identify both change entries, the one linked to @Execution and @BeforeExecution(this one with the suffix `_before`)
     * Equivalent to field `id` in ChangeSet annotation
     *
     * @return Change unit's id
     */
    String id();

    /**
     * Equivalent to field `order` in ChangeSet annotation and ChangeLog,
     * as now there is only one "changeSet", annotated with @Execution
     *
     * @return ChangeSet's author
     */
    String order();

    /**
     * Equivalent to field `author` in ChangeSet annotation
     *
     * @return ChangeSet's author
     */
    String author() default "default_author";

    /**
     * Equivalent to field `failFast` in ChangeSet annotation
     *
     * @return ChangeSet if the ChangeLog is fail fast
     */
    boolean failFast() default true;

    /**
     * Equivalent to field `runAlways` in ChangeSet annotation
     *
     * @return ChangeSet if the ChangeLog is runAlways
     */
    @Deprecated
    boolean runAlways() default false;

    /**
     * Equivalent to field `systemVersion` in ChangeSet annotation
     *
     * @return ChangeSet if the ChangeLog is runAlways
     */
    String systemVersion() default "0";

    /**
     * If true, Mongock will try to run the changeUnit in a native transaction, if possible.
     *
     * @return If he changeUnit should be run in a native transaction.
     */
    boolean transactional() default true;

}
